@@ -51,14 +51,14 @@ C     Get normal random deviates
          end do
          
 C     mean(x)
-         mu = sum(x) / real(n, kind = 8)
+         mu = sum(x) / dble(n)
          
 C     sd(x)
          tmp = zero
          do i = 1, n
             tmp = tmp + (x(i) - mu)**two
          end do
-         sigma = sqrt(tmp / real(n, kind=8))
+         sigma = sqrt(tmp / dble(n))
 
 C     get Sk
          do k = 1, n
@@ -70,8 +70,8 @@ C     get Sk
          end do
 
 
-         statm(j) = ((maxval(sk) - minval(sk)) / sigma) / 
-     *        sqrt(real(n, kind=8))
+         statm(j) = ((maxval(sk) - minval(sk)) / sigma) /
+     *        sqrt(dble(n))
   
       end do
       call rndend()
